@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
+import sys
 import marshal
 from math import log, exp
 
@@ -17,15 +18,19 @@ class Bayes(object):
         d = {}
         d['total'] = self.total
         d['d'] = {}
-        for k, v in self.d.iteritems():
+        for k, v in self.d.items():
             d['d'][k] = v.__dict__
+        if sys.version_info[0] == 3:
+            fname = fname + '.3'
         marshal.dump(d, open(fname, 'wb'))
 
     def load(self, fname):
+        if sys.version_info[0] == 3:
+            fname = fname + '.3'
         d = marshal.load(open(fname, 'rb'))
         self.total = d['total']
         self.d = {}
-        for k, v in d['d'].iteritems():
+        for k, v in d['d'].items():
             self.d[k] = AddOneProb()
             self.d[k].__dict__ = v
 
